pub struct MsgDelegateKeys {
pub validator_address: String,
pub orchestrator_address: String,
pub ethereum_address: String,
pub eth_signature: Vec<u8>,
}Expand description
MsgDelegateKey allows validators to delegate their voting responsibilities to a given orchestrator address. This key is then used as an optional authentication method for attesting events from Ethereum.
Fields
validator_address: Stringorchestrator_address: Stringethereum_address: Stringeth_signature: Vec<u8>Trait Implementations
Sourceimpl Clone for MsgDelegateKeys
impl Clone for MsgDelegateKeys
Sourcefn clone(&self) -> MsgDelegateKeys
fn clone(&self) -> MsgDelegateKeys
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MsgDelegateKeys
impl Debug for MsgDelegateKeys
Sourceimpl Default for MsgDelegateKeys
impl Default for MsgDelegateKeys
Sourceimpl Message for MsgDelegateKeys
impl Message for MsgDelegateKeys
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MsgDelegateKeys
impl PartialEq for MsgDelegateKeys
impl StructuralPartialEq for MsgDelegateKeys