pub struct SendToCosmosEvent {
pub event_nonce: u64,
pub token_contract: String,
pub amount: String,
pub ethereum_sender: String,
pub cosmos_receiver: String,
pub ethereum_height: u64,
}Expand description
SendToCosmosEvent is submitted when the SendToCosmosEvent is emitted by they gravity contract. ERC20 representation coins are minted to the cosmosreceiver address.
Fields
event_nonce: u64token_contract: Stringamount: Stringethereum_sender: Stringcosmos_receiver: Stringethereum_height: u64Trait Implementations
Sourceimpl Clone for SendToCosmosEvent
impl Clone for SendToCosmosEvent
Sourcefn clone(&self) -> SendToCosmosEvent
fn clone(&self) -> SendToCosmosEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendToCosmosEvent
impl Debug for SendToCosmosEvent
Sourceimpl Default for SendToCosmosEvent
impl Default for SendToCosmosEvent
Sourceimpl Message for SendToCosmosEvent
impl Message for SendToCosmosEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SendToCosmosEvent
impl PartialEq for SendToCosmosEvent
impl StructuralPartialEq for SendToCosmosEvent