pub struct SignerSetTxConfirmation {
pub signer_set_nonce: u64,
pub ethereum_signer: String,
pub signature: Vec<u8>,
}Expand description
SignerSetTxConfirmation is a signature on behalf of a validator for a SignerSetTx
Fields
signer_set_nonce: u64ethereum_signer: Stringsignature: Vec<u8>Trait Implementations
Sourceimpl Clone for SignerSetTxConfirmation
impl Clone for SignerSetTxConfirmation
Sourcefn clone(&self) -> SignerSetTxConfirmation
fn clone(&self) -> SignerSetTxConfirmation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignerSetTxConfirmation
impl Debug for SignerSetTxConfirmation
Sourceimpl Default for SignerSetTxConfirmation
impl Default for SignerSetTxConfirmation
Sourceimpl Message for SignerSetTxConfirmation
impl Message for SignerSetTxConfirmation
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SignerSetTxConfirmation
impl PartialEq for SignerSetTxConfirmation
impl StructuralPartialEq for SignerSetTxConfirmation